"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const S3 = require("aws-sdk/clients/s3");
const utils_1 = require("../lib/utils");
const constants_1 = require("../lib/constants");
class S3Adapter {
    constructor(config) {
        this.config = config;
        this.client = new S3(this.config.storage);
    }
    static init(config) {
        return new S3Adapter(config);
    }
    set(value, path) {
        return __awaiter(this, void 0, void 0, function* () {
            let fileKey = utils_1.documentPath(path);
            let params = {
                Body: JSON.stringify(value),
                Bucket: this.config.storage.bucket,
                Key: fileKey
            };
            try {
                let data = yield this.client.putObject(params).promise();
                return data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    update(value, path) {
        return __awaiter(this, void 0, void 0, function* () {
            let doc;
            try {
                doc = yield this.get(path);
                // Loop through all property for custom object actions
                for (let prop in value) {
                    if (value[prop] === constants_1.default.deleteValue) {
                        // If has deleteValue action, delete the prop
                        delete value[prop];
                        delete doc[prop];
                    }
                }
                let updatedValue = Object.assign({}, doc, value);
                return yield this.set(updatedValue, path);
            }
            catch (err) {
                throw err;
            }
        });
    }
    get(path) {
        return __awaiter(this, void 0, void 0, function* () {
            let fileKey = utils_1.documentPath(path);
            let params = {
                Bucket: this.config.storage.bucket,
                Key: fileKey
            };
            let data;
            try {
                data = yield this.client.getObject(params).promise();
                // Convert Buffer to object
                data.Body = data.Body.toString('utf8');
                data.Body = JSON.parse(data.Body);
                return data.Body;
            }
            catch (err) {
                throw err;
            }
        });
    }
    remove(path) {
        return __awaiter(this, void 0, void 0, function* () {
            let fileKey = utils_1.documentPath(path);
            let params = {
                Bucket: this.config.storage.bucket,
                Key: fileKey
            };
            try {
                let data;
                data = yield this.client.deleteObject(params).promise();
                return data;
            }
            catch (err) {
                throw err;
            }
        });
    }
}
exports.S3Adapter = S3Adapter;
//# sourceMappingURL=s3.js.map