import { IConfig, PathList, IDBConfig, BaseEntity, Payload, IStorageAdapter } from '../types';
import { Cache } from '../internal';
export declare class NearDB {
    /** Config that is used to init NearDB */
    config: IDBConfig;
    /** UUID of Instance of NearDB */
    instanceId: string;
    adapter: IStorageAdapter;
    static field: {
        deleteValue: string;
    };
    /**
     * Constructor to setup config, and path, and required checks.
     * @param config configuration to initialize NearDB instance
     */
    constructor(config: IConfig);
    /**
     * Static method to create a new instance of NearDB class.
     * @param config configuration to initialize NearDB instance
     * @returns an initialized instance of NearDB with the config
     */
    static database(config: IConfig): NearDB;
    /**
     * Returns a new instance of collection
     * @param key expects key for collection
     * @returns an instance of the collection class
     */
    collection(key: string): Collection;
}
export declare class Collection implements BaseEntity {
    readonly path: PathList;
    readonly instance: NearDB;
    constructor(instance: NearDB, key: string, path?: PathList);
    doc(key: string): Document;
    /**
     * Adds a document to a collection by generating an id for the doc
     * @param value expects payload to be stored for the document
     * @returns a promise for the payload of the saved doc
     */
    add(value: Payload): Promise<object>;
}
export declare class Document implements BaseEntity {
    /** Data path that is used to interact with storage */
    readonly path: PathList;
    /** Instance of NearDB with all the configuration and env settings */
    readonly instance: NearDB;
    /** Offline cache of data */
    readonly cache: Cache;
    /** String path for storage */
    constructor(instance: NearDB, key: string, path: PathList);
    /**
     * Creates a new instance of Collection
     * @param key expects key for collection
     * @returns an instance of the collection class
     */
    collection(key: string): Collection;
    /**
     * Sets document data from the path provided in the scope.
     * @param value expects payload to be stored for the document
     * @returns payload of the document requested
     */
    set(value: Payload): Promise<object>;
    /**
     * Gets document data from the path provided in the scope.
     * @param options sets options on how to get documents
     * @returns payload of the document requested
     */
    get(): Promise<object>;
    /**
     * Update some fields of the document without overwriting entire document
     * @param value expects payload to be stored for the document
     * @returns a promise for the payload requested
     */
    update(value: Payload): Promise<Payload>;
    /**
     * Removes document store in the path of instance
     * @returns payload of the document requested
     */
    delete(): Promise<object>;
}
