import { NearDB } from './lib/core';
export interface IDBConfig extends IConfig {
    cacheExpiration: number;
}
export interface IConfig {
    instanceUrl?: string;
    headers?: {
        [key: string]: string;
    };
    cacheExpiration: number;
    storage?: {
        bucket: string;
        endpoint?: string;
        useSSL: boolean;
        s3ForcePathStyle: boolean;
        signatureVersion: string;
        accessKeyId: string;
        secretAccessKey: string;
    };
}
export interface ICache {
    readonly store: Payload;
    readonly cacheExpiration: number;
    readonly expires: number;
    readonly etag: string;
    readonly versionId: string;
    set(data: Payload): void;
    get(): Payload;
    exists(): boolean;
    clear(): void;
}
export interface IStorageAdapter {
    readonly config: IConfig;
    readonly client: any;
    get(path: PathList): Promise<object>;
    set(value: object, path: PathList, metadata?: {
        [key: string]: any;
    }): Promise<object>;
    update(value: object, path: PathList, metadata?: {
        [key: string]: any;
    }): Promise<object>;
    remove(path: PathList): Promise<object>;
}
export interface BaseEntity {
    instance: NearDB;
    path: PathList;
}
export declare type GetOptions = {
    source: string;
};
export declare type PathList = PathItem[];
export declare type PathItem = {
    type: string;
    key: string;
};
export declare type Payload = {
    [key: string]: any;
};
